import json
import math
import time
from datetime import datetime, timedelta
from typing import Any, Dict, List, Optional, Tuple

import certifi
import grpc
from dateutil.parser import isoparse

from neurionpy.sanctum.msg_client import SanctumMsgClient
from neurionpy.crucible.msg_client import CrucibleMsgClient
from neurionpy.fusion.msg_client import FusionMsgClient
from neurionpy.ganglion.msg_client import GanglionMsgClient
from neurionpy.synapse.client.bank import create_bank_send_msg
from neurionpy.synapse.client.distribution import create_withdraw_delegator_reward
from neurionpy.synapse.client.staking import (
    ValidatorStatus,
    create_delegate_msg,
    create_redelegate_msg,
    create_undelegate_msg,
)
from neurionpy.synapse.client.utils import (
    ensure_timedelta,
    get_paginated,
    prepare_and_broadcast_basic_transaction,
)
from neurionpy.synapse.config import NetworkConfig
from neurionpy.synapse.exceptions import NotFoundError, QueryTimeoutError
from neurionpy.synapse.gas import GasStrategy, SimulationGasStrategy
from neurionpy.synapse.tx import Transaction, TxState
from neurionpy.synapse.tx_helpers import MessageLog, SubmittedTx, TxResponse
from neurionpy.synapse.urls import Protocol, parse_url
from neurionpy.synapse.utils import NeurionUtils
from neurionpy.synapse.utils.types import Coin, Validator, StakingPosition, StakingSummary, \
    COSMOS_SDK_DEC_COIN_PRECISION, UnbondingPositions, Account, DEFAULT_QUERY_INTERVAL_SECS, DEFAULT_QUERY_TIMEOUT_SECS, \
    Block
from neurionpy.synapse.wallet import Wallet
from neurionpy.auth.rest_client import AuthRestClient
from neurionpy.bank.rest_client import BankRestClient
from neurionpy.common.rest_client import RestClient
from neurionpy.consensus.rest_client import ConsensusRestClient
from neurionpy.sanctum.rest_client import SanctumRestClient
from neurionpy.crucible.rest_client import CrucibleRestClient
from neurionpy.fusion.rest_client import FusionRestClient
from neurionpy.ganglion.rest_client import GanglionRestClient
from neurionpy.cosmwasm.rest_client import CosmWasmRestClient
from neurionpy.crypto.address import Address
from neurionpy.distribution.rest_client import DistributionRestClient
from neurionpy.params.rest_client import ParamsRestClient
from neurionpy.protos.cosmos.auth.v1beta1.auth_pb2 import BaseAccount
from neurionpy.protos.cosmos.auth.v1beta1.query_pb2 import QueryAccountRequest
from neurionpy.protos.cosmos.auth.v1beta1.query_pb2_grpc import QueryStub as AuthGrpcClient
from neurionpy.protos.cosmos.bank.v1beta1.query_pb2 import (
    QueryAllBalancesRequest,
    QueryBalanceRequest,
)
from neurionpy.protos.cosmos.bank.v1beta1.query_pb2_grpc import QueryStub as BankGrpcClient
from neurionpy.protos.cosmos.base.tendermint.v1beta1.query_pb2 import (
    GetBlockByHeightRequest,
    GetLatestBlockRequest,
)
from neurionpy.protos.cosmos.base.tendermint.v1beta1.query_pb2_grpc import (
    ServiceStub as TendermintQueryGrpcClient,
)
from neurionpy.protos.cosmos.crypto.ed25519.keys_pb2 import (  # noqa # pylint: disable=unused-import
    PubKey,
)
from neurionpy.protos.cosmos.distribution.v1beta1.query_pb2 import (
    QueryDelegationRewardsRequest,
)
from neurionpy.protos.cosmos.distribution.v1beta1.query_pb2_grpc import (
    QueryStub as DistributionGrpcClient,
)
from neurionpy.protos.cosmos.params.v1beta1.query_pb2 import QueryParamsRequest
from neurionpy.protos.cosmos.params.v1beta1.query_pb2_grpc import (
    QueryStub as QueryParamsGrpcClient,
)
from neurionpy.protos.cosmos.staking.v1beta1.query_pb2 import (
    QueryDelegatorDelegationsRequest,
    QueryDelegatorUnbondingDelegationsRequest,
    QueryValidatorsRequest,
)
from neurionpy.protos.cosmos.staking.v1beta1.query_pb2_grpc import (
    QueryStub as StakingGrpcClient,
)

from neurionpy.protos.cosmos.tx.v1beta1.service_pb2 import (
    BroadcastMode,
    BroadcastTxRequest,
    GetTxRequest,
    SimulateRequest,
)
from neurionpy.protos.cosmos.tx.v1beta1.service_pb2_grpc import ServiceStub as TxGrpcClient
from neurionpy.protos.cosmwasm.wasm.v1.query_pb2_grpc import (
    QueryStub as CosmWasmGrpcClient,
)
from neurionpy.staking.rest_client import StakingRestClient
from neurionpy.tendermint.rest_client import (
    CosmosBaseTendermintRestClient as TendermintRestClient,
)
from neurionpy.protos.cosmos.consensus.v1.query_pb2_grpc import QueryStub as ConsensusGrpcClient
from neurionpy.protos.neurion.sanctum.query_pb2_grpc import QueryStub as SanctumGrpcClient
from neurionpy.protos.neurion.crucible.query_pb2_grpc import QueryStub as CrucibleGrpcClient
from neurionpy.protos.neurion.fusion.query_pb2_grpc import QueryStub as FusionGrpcClient
from neurionpy.protos.neurion.ganglion.query_pb2_grpc import QueryStub as GanglionGrpcClient
from neurionpy.tx.rest_client import TxRestClient


class NeurionClient:
    """Neurion client."""

    def __init__(
            self,
            cfg: NetworkConfig,
            wallet: Optional[Wallet] = None,
            query_interval_secs: int = DEFAULT_QUERY_INTERVAL_SECS,
            query_timeout_secs: int = DEFAULT_QUERY_TIMEOUT_SECS,
    ):
        """Init neurion client.

        :param cfg: Network configurations
        :param query_interval_secs: int. optional interval int seconds
        :param query_timeout_secs: int. optional interval int seconds
        :param wallet: Wallet, defaults to None
        """
        self._query_interval_secs = query_interval_secs
        self._query_timeout_secs = query_timeout_secs
        cfg.validate()
        self._network_config = cfg
        self._gas_strategy: GasStrategy = SimulationGasStrategy(self)
        self.wallet = wallet

        parsed_url = parse_url(cfg.url)

        if parsed_url.protocol == Protocol.GRPC:
            if parsed_url.secure:
                with open(certifi.where(), "rb") as f:
                    trusted_certs = f.read()
                credentials = grpc.ssl_channel_credentials(
                    root_certificates=trusted_certs
                )
                grpc_client = grpc.secure_channel(parsed_url.host_and_port, credentials)
            else:
                grpc_client = grpc.insecure_channel(parsed_url.host_and_port)

            self.wasm = CosmWasmGrpcClient(grpc_client)
            self.auth = AuthGrpcClient(grpc_client)
            self.txs = TxGrpcClient(grpc_client)
            self.bank = BankGrpcClient(grpc_client)
            self.staking = StakingGrpcClient(grpc_client)
            self.distribution = DistributionGrpcClient(grpc_client)
            self.params = QueryParamsGrpcClient(grpc_client)
            self.tendermint = TendermintQueryGrpcClient(grpc_client)
            self.consensus = ConsensusGrpcClient(grpc_client)
            self.sanctum = SanctumGrpcClient(grpc_client)
            self.crucible = CrucibleGrpcClient(grpc_client)
            self.fusion = FusionGrpcClient(grpc_client)
            self.ganglion = GanglionGrpcClient(grpc_client)
        else:
            rest_client = RestClient(parsed_url.rest_url)

            self.wasm = CosmWasmRestClient(rest_client)  # type: ignore
            self.auth = AuthRestClient(rest_client)  # type: ignore
            self.txs = TxRestClient(rest_client)  # type: ignore
            self.bank = BankRestClient(rest_client)  # type: ignore
            self.staking = StakingRestClient(rest_client)  # type: ignore
            self.distribution = DistributionRestClient(rest_client)  # type: ignore
            self.params = ParamsRestClient(rest_client)  # type: ignore
            self.tendermint = TendermintRestClient(rest_client)  # type: ignore
            self.consensus = ConsensusRestClient(rest_client)  # type: ignore
            self.sanctum = SanctumRestClient(rest_client)  # type: ignore
            self.crucible = CrucibleRestClient(rest_client)  # type: ignore
            self.fusion = FusionRestClient(rest_client)  # type: ignore
            self.ganglion = GanglionRestClient(rest_client)  # type: ignore

        self.utils = NeurionUtils(cfg, self.auth, self.params, self.bank, self.staking, self.distribution, self.txs,
                                  self.tendermint, self._gas_strategy)

        self.sanctum.tx = SanctumMsgClient(self.utils, self.wallet)
        self.crucible.tx = CrucibleMsgClient(self.utils, self.wallet)
        self.fusion.tx = FusionMsgClient(self.utils, self.wallet)
        self.ganglion.tx = GanglionMsgClient(self.utils, self.wallet)


    @property
    def network_config(self) -> NetworkConfig:
        """Get the network config.

        :return: network config
        """
        return self._network_config

    @property
    def gas_strategy(self) -> GasStrategy:
        """Get gas strategy.

        :return: gas strategy
        """
        return self._gas_strategy

    @gas_strategy.setter
    def gas_strategy(self, strategy: GasStrategy):
        """Set gas strategy.

        :param strategy: strategy
        :raises RuntimeError: Invalid strategy must implement GasStrategy interface
        """
        if not isinstance(strategy, GasStrategy):
            raise RuntimeError("Invalid strategy must implement GasStrategy interface")
        self._gas_strategy = strategy

    def query_account(self, address: Address) -> Account:
        """Query account.

        :param address: address
        :raises RuntimeError: Unexpected account type returned from query
        :return: account details
        """
        request = QueryAccountRequest(address=str(address))
        response = self.auth.Account(request)

        account = BaseAccount()
        if not response.account.Is(BaseAccount.DESCRIPTOR):
            raise RuntimeError("Unexpected account type returned from query")
        response.account.Unpack(account)

        return Account(
            address=address,
            number=account.account_number,
            sequence=account.sequence,
        )

    def query_params(self, subspace: str, key: str) -> Any:
        """Query Prams.

        :param subspace: subspace
        :param key: key
        :return: Query params
        """
        req = QueryParamsRequest(subspace=subspace, key=key)
        resp = self.params.Params(req)
        return json.loads(resp.param.value)

    def query_bank_balance(self, address: Address, denom: Optional[str] = None) -> int:
        """Query bank balance.

        :param address: address
        :param denom: denom, defaults to None
        :return: bank balance
        """
        denom = denom or self.network_config.fee_denomination

        req = QueryBalanceRequest(
            address=str(address),
            denom=denom,
        )

        resp = self.bank.Balance(req)
        assert resp.balance.denom == denom  # sanity check

        return resp.balance.amount

    def query_bank_all_balances(self, address: Address) -> List[Coin]:
        """Query bank all balances.

        :param address: address
        :return: bank all balances
        """
        req = QueryAllBalancesRequest(address=str(address))
        resp = self.bank.AllBalances(req)

        return [Coin(amount=coin.amount, denom=coin.denom) for coin in resp.balances]

    def send_tokens(
            self,
            destination: Address,
            amount: int,
            denom: str,
            sender: Wallet,
            memo: Optional[str] = None,
            gas_limit: Optional[int] = None,
    ) -> SubmittedTx:
        """Send tokens.

        :param destination: destination address
        :param amount: amount
        :param denom: denom
        :param sender: sender
        :param memo: memo, defaults to None
        :param gas_limit: gas limit, defaults to None
        :return: prepare and broadcast the transaction and transaction details
        """
        # build up the store transaction
        tx = Transaction()
        tx.add_message(
            create_bank_send_msg(sender.address(), destination, amount, denom)
        )

        return prepare_and_broadcast_basic_transaction(
            self, tx, sender, gas_limit=gas_limit, memo=memo
        )

    def query_validators(
            self, status: Optional[ValidatorStatus] = None
    ) -> List[Validator]:
        """Query validators.

        :param status: validator status, defaults to None
        :return: List of validators
        """
        filtered_status = status or ValidatorStatus.BONDED

        req = QueryValidatorsRequest()
        if filtered_status != ValidatorStatus.UNSPECIFIED:
            req.status = filtered_status.value

        resp = self.staking.Validators(req)

        validators: List[Validator] = []
        for validator in resp.validators:
            validators.append(
                Validator(
                    address=Address(validator.operator_address),
                    tokens=int(float(validator.tokens)),
                    moniker=str(validator.description.moniker),
                    status=ValidatorStatus.from_proto(validator.status),
                )
            )
        return validators

    def query_staking_summary(self, address: Address) -> StakingSummary:
        """Query staking summary.

        :param address: address
        :return: staking summary
        """
        current_positions: List[StakingPosition] = []

        req = QueryDelegatorDelegationsRequest(delegator_addr=str(address))

        for resp in get_paginated(
                req, self.staking.DelegatorDelegations, per_page_limit=1
        ):
            for item in resp.delegation_responses:
                req = QueryDelegationRewardsRequest(
                    delegator_address=str(address),
                    validator_address=str(item.delegation.validator_address),
                )
                rewards_resp = self.distribution.DelegationRewards(req)

                stake_reward = 0
                for reward in rewards_resp.rewards:
                    if reward.denom == self.network_config.staking_denomination:
                        stake_reward = (
                                int(float(reward.amount)) // COSMOS_SDK_DEC_COIN_PRECISION
                        )
                        break

                current_positions.append(
                    StakingPosition(
                        validator=Address(item.delegation.validator_address),
                        amount=int(float(item.balance.amount)),
                        reward=stake_reward,
                    )
                )

        unbonding_summary: Dict[str, int] = {}
        req = QueryDelegatorUnbondingDelegationsRequest(delegator_addr=str(address))

        for resp in get_paginated(req, self.staking.DelegatorUnbondingDelegations):
            for item in resp.unbonding_responses:
                validator = str(item.validator_address)
                total_unbonding = unbonding_summary.get(validator, 0)

                for entry in item.entries:
                    total_unbonding += int(float(entry.balance))

                unbonding_summary[validator] = total_unbonding

        # build the final list of unbonding positions
        unbonding_positions: List[UnbondingPositions] = []
        for validator, total_unbonding in unbonding_summary.items():
            unbonding_positions.append(
                UnbondingPositions(
                    validator=Address(validator),
                    amount=total_unbonding,
                )
            )

        return StakingSummary(
            current_positions=current_positions, unbonding_positions=unbonding_positions
        )

    def delegate_tokens(
            self,
            validator: Address,
            amount: int,
            sender: Wallet,
            memo: Optional[str] = None,
            gas_limit: Optional[int] = None,
    ) -> SubmittedTx:
        """Delegate tokens.

        :param validator: validator address
        :param amount: amount
        :param sender: sender
        :param memo: memo, defaults to None
        :param gas_limit: gas limit, defaults to None
        :return: prepare and broadcast the transaction and transaction details
        """
        tx = Transaction()
        tx.add_message(
            create_delegate_msg(
                sender.address(),
                validator,
                amount,
                self.network_config.staking_denomination,
            )
        )

        return prepare_and_broadcast_basic_transaction(
            self, tx, sender, gas_limit=gas_limit, memo=memo
        )

    def redelegate_tokens(
            self,
            current_validator: Address,
            next_validator: Address,
            amount: int,
            sender: Wallet,
            memo: Optional[str] = None,
            gas_limit: Optional[int] = None,
    ) -> SubmittedTx:
        """Redelegate tokens.

        :param current_validator: current validator address
        :param next_validator: next validator address
        :param amount: amount
        :param sender: sender
        :param memo: memo, defaults to None
        :param gas_limit: gas limit, defaults to None
        :return: prepare and broadcast the transaction and transaction details
        """
        tx = Transaction()
        tx.add_message(
            create_redelegate_msg(
                sender.address(),
                current_validator,
                next_validator,
                amount,
                self.network_config.staking_denomination,
            )
        )

        return prepare_and_broadcast_basic_transaction(
            self, tx, sender, gas_limit=gas_limit, memo=memo
        )

    def undelegate_tokens(
            self,
            validator: Address,
            amount: int,
            sender: Wallet,
            memo: Optional[str] = None,
            gas_limit: Optional[int] = None,
    ) -> SubmittedTx:
        """Undelegate tokens.

        :param validator: validator
        :param amount: amount
        :param sender: sender
        :param memo: memo, defaults to None
        :param gas_limit: gas limit, defaults to None
        :return: prepare and broadcast the transaction and transaction details
        """
        tx = Transaction()
        tx.add_message(
            create_undelegate_msg(
                sender.address(),
                validator,
                amount,
                self.network_config.staking_denomination,
            )
        )

        return prepare_and_broadcast_basic_transaction(
            self, tx, sender, gas_limit=gas_limit, memo=memo
        )

    def claim_rewards(
            self,
            validator: Address,
            sender: Wallet,
            memo: Optional[str] = None,
            gas_limit: Optional[int] = None,
    ) -> SubmittedTx:
        """claim rewards.

        :param validator: validator
        :param sender: sender
        :param memo: memo, defaults to None
        :param gas_limit: gas limit, defaults to None
        :return: prepare and broadcast the transaction and transaction details
        """
        tx = Transaction()
        tx.add_message(create_withdraw_delegator_reward(sender.address(), validator))

        return prepare_and_broadcast_basic_transaction(
            self, tx, sender, gas_limit=gas_limit, memo=memo
        )

    def estimate_gas_for_tx(self, tx: Transaction) -> int:
        """Estimate gas for transaction.

        :param tx: transaction
        :return: Estimated gas for transaction
        """
        return self._gas_strategy.estimate_gas(tx)

    def estimate_fee_from_gas(self, gas_limit: int) -> str:
        """Estimate fee from gas.

        :param gas_limit: gas limit
        :return: Estimated fee for transaction
        """
        fee = math.ceil(gas_limit * self.network_config.fee_minimum_gas_price)
        return f"{fee}{self.network_config.fee_denomination}"

    def estimate_gas_and_fee_for_tx(self, tx: Transaction) -> Tuple[int, str]:
        """Estimate gas and fee for transaction.

        :param tx: transaction
        :return: estimate gas, fee for transaction
        """
        gas_estimate = self.estimate_gas_for_tx(tx)
        fee = self.estimate_fee_from_gas(gas_estimate)
        return gas_estimate, fee

    def wait_for_query_tx(
            self,
            tx_hash: str,
            timeout: Optional[timedelta] = None,
            poll_period: Optional[timedelta] = None,
    ) -> TxResponse:
        """Wait for query transaction.

        :param tx_hash: transaction hash
        :param timeout: timeout, defaults to None
        :param poll_period: poll_period, defaults to None

        :raises QueryTimeoutError: timeout

        :return: transaction response
        """
        timeout = (
            ensure_timedelta(timeout)
            if timeout
            else timedelta(seconds=self._query_timeout_secs)
        )
        poll_period = (
            ensure_timedelta(poll_period)
            if poll_period
            else timedelta(seconds=self._query_interval_secs)
        )

        start = datetime.now()
        while True:
            try:
                return self.query_tx(tx_hash)
            except NotFoundError:
                pass

            delta = datetime.now() - start
            if delta >= timeout:
                raise QueryTimeoutError()

            time.sleep(poll_period.total_seconds())

    def query_tx(self, tx_hash: str) -> TxResponse:
        """query transaction.

        :param tx_hash: transaction hash
        :raises NotFoundError: Tx details not found
        :raises grpc.RpcError: RPC connection issue
        :return: query response
        """
        req = GetTxRequest(hash=tx_hash)
        try:
            resp = self.txs.GetTx(req)
        except grpc.RpcError as e:
            details = e.details()
            if "not found" in details:
                raise NotFoundError() from e
            raise
        except RuntimeError as e:
            details = str(e)
            if "tx" in details and "not found" in details:
                raise NotFoundError() from e
            raise

        return self._parse_tx_response(resp.tx_response)

    @staticmethod
    def _parse_tx_response(tx_response: Any) -> TxResponse:
        # parse the transaction logs
        logs = []
        for log_data in tx_response.logs:
            events = {}
            for event in log_data.events:
                events[event.type] = {a.key: a.value for a in event.attributes}
            logs.append(
                MessageLog(
                    index=int(log_data.msg_index), log=log_data.msg_index, events=events
                )
            )

        # parse the transaction events
        events = {}
        for event in tx_response.events:
            event_data = events.get(event.type, {})
            for attribute in event.attributes:
                event_data[attribute.key.decode()] = attribute.value.decode()
            events[event.type] = event_data

        timestamp = None
        if tx_response.timestamp:
            timestamp = isoparse(tx_response.timestamp)

        return TxResponse(
            hash=str(tx_response.txhash),
            height=int(tx_response.height),
            code=int(tx_response.code),
            gas_wanted=int(tx_response.gas_wanted),
            gas_used=int(tx_response.gas_used),
            raw_log=str(tx_response.raw_log),
            logs=logs,
            events=events,
            timestamp=timestamp,
        )

    def simulate_tx(self, tx: Transaction) -> int:
        """simulate transaction.

        :param tx: transaction
        :raises RuntimeError: Unable to simulate non final transaction
        :return: gas used in transaction
        """
        if tx.state != TxState.Final:
            raise RuntimeError("Unable to simulate non final transaction")

        req = SimulateRequest(tx=tx.tx)
        resp = self.txs.Simulate(req)

        return int(resp.gas_info.gas_used)

    def broadcast_tx(self, tx: Transaction) -> SubmittedTx:
        """Broadcast transaction.

        :param tx: transaction
        :return: Submitted transaction
        """
        # create the broadcast request
        broadcast_req = BroadcastTxRequest(
            tx_bytes=tx.tx.SerializeToString(), mode=BroadcastMode.BROADCAST_MODE_SYNC
        )

        # broadcast the transaction
        resp = self.txs.BroadcastTx(broadcast_req)
        tx_digest = resp.tx_response.txhash

        # check that the response is successful
        initial_tx_response = self._parse_tx_response(resp.tx_response)
        initial_tx_response.ensure_successful()

        return SubmittedTx(self, tx_digest)

    def query_latest_block(self) -> Block:
        """Query the latest block.

        :return: latest block
        """
        req = GetLatestBlockRequest()
        resp = self.tendermint.GetLatestBlock(req)
        return Block.from_proto(resp.block)

    def query_block(self, height: int) -> Block:
        """Query the block.

        :param height: block height
        :return: block
        """
        req = GetBlockByHeightRequest(height=height)
        resp = self.tendermint.GetBlockByHeight(req)
        return Block.from_proto(resp.block)

    def query_height(self) -> int:
        """Query the latest block height.

        :return: latest block height
        """
        return self.query_latest_block().height

    def query_chain_id(self) -> str:
        """Query the chain id.

        :return: chain id
        """
        return self.query_latest_block().chain_id



from amino import amino_pb2 as _amino_pb2
from gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class Params(_message.Message):
    __slots__ = ("min_dataset_stake", "min_dataset_fee", "admin_address", "protocol_fee", "protocol_deposit", "request_processing_fee", "staker_reward_percentage")
    MIN_DATASET_STAKE_FIELD_NUMBER: _ClassVar[int]
    MIN_DATASET_FEE_FIELD_NUMBER: _ClassVar[int]
    ADMIN_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    PROTOCOL_FEE_FIELD_NUMBER: _ClassVar[int]
    PROTOCOL_DEPOSIT_FIELD_NUMBER: _ClassVar[int]
    REQUEST_PROCESSING_FEE_FIELD_NUMBER: _ClassVar[int]
    STAKER_REWARD_PERCENTAGE_FIELD_NUMBER: _ClassVar[int]
    min_dataset_stake: int
    min_dataset_fee: int
    admin_address: str
    protocol_fee: int
    protocol_deposit: int
    request_processing_fee: int
    staker_reward_percentage: int
    def __init__(self, min_dataset_stake: _Optional[int] = ..., min_dataset_fee: _Optional[int] = ..., admin_address: _Optional[str] = ..., protocol_fee: _Optional[int] = ..., protocol_deposit: _Optional[int] = ..., request_processing_fee: _Optional[int] = ..., staker_reward_percentage: _Optional[int] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Message(_message.Message):
    __slots__ = ("snapshots_request", "snapshots_response", "chunk_request", "chunk_response")
    SNAPSHOTS_REQUEST_FIELD_NUMBER: _ClassVar[int]
    SNAPSHOTS_RESPONSE_FIELD_NUMBER: _ClassVar[int]
    CHUNK_REQUEST_FIELD_NUMBER: _ClassVar[int]
    CHUNK_RESPONSE_FIELD_NUMBER: _ClassVar[int]
    snapshots_request: SnapshotsRequest
    snapshots_response: SnapshotsResponse
    chunk_request: ChunkRequest
    chunk_response: ChunkResponse
    def __init__(self, snapshots_request: _Optional[_Union[SnapshotsRequest, _Mapping]] = ..., snapshots_response: _Optional[_Union[SnapshotsResponse, _Mapping]] = ..., chunk_request: _Optional[_Union[ChunkRequest, _Mapping]] = ..., chunk_response: _Optional[_Union[ChunkResponse, _Mapping]] = ...) -> None: ...

class SnapshotsRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class SnapshotsResponse(_message.Message):
    __slots__ = ("height", "format", "chunks", "hash", "metadata")
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    FORMAT_FIELD_NUMBER: _ClassVar[int]
    CHUNKS_FIELD_NUMBER: _ClassVar[int]
    HASH_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    height: int
    format: int
    chunks: int
    hash: bytes
    metadata: bytes
    def __init__(self, height: _Optional[int] = ..., format: _Optional[int] = ..., chunks: _Optional[int] = ..., hash: _Optional[bytes] = ..., metadata: _Optional[bytes] = ...) -> None: ...

class ChunkRequest(_message.Message):
    __slots__ = ("height", "format", "index")
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    FORMAT_FIELD_NUMBER: _ClassVar[int]
    INDEX_FIELD_NUMBER: _ClassVar[int]
    height: int
    format: int
    index: int
    def __init__(self, height: _Optional[int] = ..., format: _Optional[int] = ..., index: _Optional[int] = ...) -> None: ...

class ChunkResponse(_message.Message):
    __slots__ = ("height", "format", "index", "chunk", "missing")
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    FORMAT_FIELD_NUMBER: _ClassVar[int]
    INDEX_FIELD_NUMBER: _ClassVar[int]
    CHUNK_FIELD_NUMBER: _ClassVar[int]
    MISSING_FIELD_NUMBER: _ClassVar[int]
    height: int
    format: int
    index: int
    chunk: bytes
    missing: bool
    def __init__(self, height: _Optional[int] = ..., format: _Optional[int] = ..., index: _Optional[int] = ..., chunk: _Optional[bytes] = ..., missing: bool = ...) -> None: ...



from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class TaskStatus(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    TASK_STATUS_CREATED: _ClassVar[TaskStatus]
    TASK_STATUS_PROPOSING: _ClassVar[TaskStatus]
    TASK_STATUS_TESTING: _ClassVar[TaskStatus]
    TASK_STATUS_DISPUTE: _ClassVar[TaskStatus]
    TASK_STATUS_TERMINATED: _ClassVar[TaskStatus]
    TASK_STATUS_ABORTED: _ClassVar[TaskStatus]
TASK_STATUS_CREATED: TaskStatus
TASK_STATUS_PROPOSING: TaskStatus
TASK_STATUS_TESTING: TaskStatus
TASK_STATUS_DISPUTE: TaskStatus
TASK_STATUS_TERMINATED: TaskStatus
TASK_STATUS_ABORTED: TaskStatus

class Task(_message.Message):
    __slots__ = ("id", "creator", "name", "description", "reward", "base_models", "test_data", "created_timestamp", "proposed_timestamps", "testing_timestamps", "dispute_timestamps", "terminated_timestamp", "aborted_timestamp", "status", "max_rounds", "current_round")
    ID_FIELD_NUMBER: _ClassVar[int]
    CREATOR_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    REWARD_FIELD_NUMBER: _ClassVar[int]
    BASE_MODELS_FIELD_NUMBER: _ClassVar[int]
    TEST_DATA_FIELD_NUMBER: _ClassVar[int]
    CREATED_TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    PROPOSED_TIMESTAMPS_FIELD_NUMBER: _ClassVar[int]
    TESTING_TIMESTAMPS_FIELD_NUMBER: _ClassVar[int]
    DISPUTE_TIMESTAMPS_FIELD_NUMBER: _ClassVar[int]
    TERMINATED_TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    ABORTED_TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    MAX_ROUNDS_FIELD_NUMBER: _ClassVar[int]
    CURRENT_ROUND_FIELD_NUMBER: _ClassVar[int]
    id: int
    creator: str
    name: str
    description: str
    reward: int
    base_models: _containers.RepeatedScalarFieldContainer[str]
    test_data: _containers.RepeatedScalarFieldContainer[str]
    created_timestamp: int
    proposed_timestamps: _containers.RepeatedScalarFieldContainer[int]
    testing_timestamps: _containers.RepeatedScalarFieldContainer[int]
    dispute_timestamps: _containers.RepeatedScalarFieldContainer[int]
    terminated_timestamp: int
    aborted_timestamp: int
    status: TaskStatus
    max_rounds: int
    current_round: int
    def __init__(self, id: _Optional[int] = ..., creator: _Optional[str] = ..., name: _Optional[str] = ..., description: _Optional[str] = ..., reward: _Optional[int] = ..., base_models: _Optional[_Iterable[str]] = ..., test_data: _Optional[_Iterable[str]] = ..., created_timestamp: _Optional[int] = ..., proposed_timestamps: _Optional[_Iterable[int]] = ..., testing_timestamps: _Optional[_Iterable[int]] = ..., dispute_timestamps: _Optional[_Iterable[int]] = ..., terminated_timestamp: _Optional[int] = ..., aborted_timestamp: _Optional[int] = ..., status: _Optional[_Union[TaskStatus, str]] = ..., max_rounds: _Optional[int] = ..., current_round: _Optional[int] = ...) -> None: ...



from abc import ABC, abstractmethod

from neurionpy.protos.cosmos.mint.v1beta1.query_pb2 import (
    QueryAnnualProvisionsResponse,
    QueryInflationResponse,
    QueryParamsResponse,
)


class Mint(ABC):
    """Mint abstract class."""

    @abstractmethod
    def AnnualProvisions(self) -> QueryAnnualProvisionsResponse:
        """
        AnnualProvisions current minting annual provisions value.

        :return: a QueryAnnualProvisionsResponse instance
        """

    @abstractmethod
    def Inflation(self) -> QueryInflationResponse:
        """
        Inflation returns the current minting inflation value.

        :return: a QueryInflationResponse instance
        """

    @abstractmethod
    def Params(self) -> QueryParamsResponse:
        """
        Params returns the total set of minting parameters.

        :return: QueryParamsResponse
        """



from abc import ABC, abstractmethod
from collections import UserString
from typing import Optional

from neurionpy.crypto.address import Address
from neurionpy.crypto.hashfuncs import sha256
from neurionpy.crypto.interface import Signer
from neurionpy.crypto.keypairs import PrivateKey, PublicKey
from neurionpy.mnemonic import COSMOS_HD_PATH, derive_child_key_from_mnemonic


class Wallet(ABC, UserString):
    """Wallet Generation.

    :param ABC: ABC abstract method
    :param UserString: user string
    """

    @abstractmethod
    def address(self) -> Address:
        """get the address of the wallet.

        :return: None
        """

    @abstractmethod
    def public_key(self) -> PublicKey:
        """get the public key of the wallet.

        :return: None
        """

    @abstractmethod
    def signer(self) -> Signer:
        """get the signer of the wallet.

        :return: None
        """

    @property
    def data(self):
        """Get the address of the wallet.

        :return: Address
        """
        return self.address()

    def __json__(self):
        """
        Return the address in string format.

        :return: address in string format
        """
        return str(self.address())


class LocalWallet(Wallet):
    """Generate local wallet.

    :param Wallet: wallet
    """

    @staticmethod
    def generate(prefix: Optional[str] = None) -> "LocalWallet":
        """generate the local wallet.

        :param prefix: prefix, defaults to None
        :return: local wallet
        """
        return LocalWallet(PrivateKey(), prefix=prefix)

    @staticmethod
    def from_mnemonic(mnemonic: str, prefix: Optional[str] = None) -> "LocalWallet":
        """Generate local wallet from mnemonic.

        :param mnemonic: mnemonic
        :param prefix: prefix, defaults to None
        :return: local wallet
        """
        child_key = derive_child_key_from_mnemonic(mnemonic, path=COSMOS_HD_PATH)

        return LocalWallet(PrivateKey(child_key), prefix=prefix)

    @staticmethod
    def from_unsafe_seed(
        text: str, index: Optional[int] = None, prefix: Optional[str] = None
    ) -> "LocalWallet":
        """Generate local wallet from unsafe seed.

        :param text: text
        :param index: index, defaults to None
        :param prefix: prefix, defaults to None
        :return: Local wallet
        """
        private_key_bytes = sha256(text.encode())
        if index is not None:
            private_key_bytes = sha256(
                private_key_bytes + index.to_bytes(4, byteorder="big")
            )
        return LocalWallet(PrivateKey(private_key_bytes), prefix=prefix)

    def __init__(self, private_key: PrivateKey, prefix: Optional[str] = None):
        """Init wallet with.

        :param private_key: private key of the wallet
        :param prefix: prefix, defaults to None
        """
        self._private_key = private_key
        self._public_key = private_key.public_key
        self._prefix = prefix

    def address(self) -> Address:
        """Get the wallet address.

        :return: Wallet address.
        """
        return Address(self._public_key, self._prefix)

    def public_key(self) -> PublicKey:
        """Get the public key of the wallet.

        :return: public key
        """
        return self._public_key

    def signer(self) -> PrivateKey:
        """Get  the signer of the wallet.

        :return: signer
        """
        return self._private_key



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ibc/core/port/v1/query.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'ibc/core/port/v1/query.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ibc.core.channel.v1 import channel_pb2 as ibc_dot_core_dot_channel_dot_v1_dot_channel__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1cibc/core/port/v1/query.proto\x12\x10ibc.core.port.v1\x1a!ibc/core/channel/v1/channel.proto\"\xc1\x01\n\x16QueryAppVersionRequest\x12\x0f\n\x07port_id\x18\x01 \x01(\t\x12\x15\n\rconnection_id\x18\x02 \x01(\t\x12,\n\x08ordering\x18\x03 \x01(\x0e\x32\x1a.ibc.core.channel.v1.Order\x12\x37\n\x0c\x63ounterparty\x18\x04 \x01(\x0b\x32!.ibc.core.channel.v1.Counterparty\x12\x18\n\x10proposed_version\x18\x05 \x01(\t\";\n\x17QueryAppVersionResponse\x12\x0f\n\x07port_id\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t2l\n\x05Query\x12\x63\n\nAppVersion\x12(.ibc.core.port.v1.QueryAppVersionRequest\x1a).ibc.core.port.v1.QueryAppVersionResponse\"\x00\x42\x38Z6github.com/cosmos/ibc-go/v2/modules/core/05-port/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.core.port.v1.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z6github.com/cosmos/ibc-go/v2/modules/core/05-port/types'
  _globals['_QUERYAPPVERSIONREQUEST']._serialized_start=86
  _globals['_QUERYAPPVERSIONREQUEST']._serialized_end=279
  _globals['_QUERYAPPVERSIONRESPONSE']._serialized_start=281
  _globals['_QUERYAPPVERSIONRESPONSE']._serialized_end=340
  _globals['_QUERY']._serialized_start=342
  _globals['_QUERY']._serialized_end=450
# @@protoc_insertion_point(module_scope)



from gogoproto import gogo_pb2 as _gogo_pb2
from cometbft.abci.v1beta1 import types_pb2 as _types_pb2
from cometbft.types.v1beta1 import types_pb2 as _types_pb2_1
from cometbft.types.v1beta1 import validator_pb2 as _validator_pb2
from cometbft.types.v1beta1 import params_pb2 as _params_pb2
from cometbft.version.v1 import types_pb2 as _types_pb2_1_1
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ABCIResponses(_message.Message):
    __slots__ = ("deliver_txs", "end_block", "begin_block")
    DELIVER_TXS_FIELD_NUMBER: _ClassVar[int]
    END_BLOCK_FIELD_NUMBER: _ClassVar[int]
    BEGIN_BLOCK_FIELD_NUMBER: _ClassVar[int]
    deliver_txs: _containers.RepeatedCompositeFieldContainer[_types_pb2.ResponseDeliverTx]
    end_block: _types_pb2.ResponseEndBlock
    begin_block: _types_pb2.ResponseBeginBlock
    def __init__(self, deliver_txs: _Optional[_Iterable[_Union[_types_pb2.ResponseDeliverTx, _Mapping]]] = ..., end_block: _Optional[_Union[_types_pb2.ResponseEndBlock, _Mapping]] = ..., begin_block: _Optional[_Union[_types_pb2.ResponseBeginBlock, _Mapping]] = ...) -> None: ...

class ValidatorsInfo(_message.Message):
    __slots__ = ("validator_set", "last_height_changed")
    VALIDATOR_SET_FIELD_NUMBER: _ClassVar[int]
    LAST_HEIGHT_CHANGED_FIELD_NUMBER: _ClassVar[int]
    validator_set: _validator_pb2.ValidatorSet
    last_height_changed: int
    def __init__(self, validator_set: _Optional[_Union[_validator_pb2.ValidatorSet, _Mapping]] = ..., last_height_changed: _Optional[int] = ...) -> None: ...

class ConsensusParamsInfo(_message.Message):
    __slots__ = ("consensus_params", "last_height_changed")
    CONSENSUS_PARAMS_FIELD_NUMBER: _ClassVar[int]
    LAST_HEIGHT_CHANGED_FIELD_NUMBER: _ClassVar[int]
    consensus_params: _params_pb2.ConsensusParams
    last_height_changed: int
    def __init__(self, consensus_params: _Optional[_Union[_params_pb2.ConsensusParams, _Mapping]] = ..., last_height_changed: _Optional[int] = ...) -> None: ...

class ABCIResponsesInfo(_message.Message):
    __slots__ = ("abci_responses", "height")
    ABCI_RESPONSES_FIELD_NUMBER: _ClassVar[int]
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    abci_responses: ABCIResponses
    height: int
    def __init__(self, abci_responses: _Optional[_Union[ABCIResponses, _Mapping]] = ..., height: _Optional[int] = ...) -> None: ...

class Version(_message.Message):
    __slots__ = ("consensus", "software")
    CONSENSUS_FIELD_NUMBER: _ClassVar[int]
    SOFTWARE_FIELD_NUMBER: _ClassVar[int]
    consensus: _types_pb2_1_1.Consensus
    software: str
    def __init__(self, consensus: _Optional[_Union[_types_pb2_1_1.Consensus, _Mapping]] = ..., software: _Optional[str] = ...) -> None: ...

class State(_message.Message):
    __slots__ = ("version", "chain_id", "initial_height", "last_block_height", "last_block_id", "last_block_time", "next_validators", "validators", "last_validators", "last_height_validators_changed", "consensus_params", "last_height_consensus_params_changed", "last_results_hash", "app_hash")
    VERSION_FIELD_NUMBER: _ClassVar[int]
    CHAIN_ID_FIELD_NUMBER: _ClassVar[int]
    INITIAL_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    LAST_BLOCK_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    LAST_BLOCK_ID_FIELD_NUMBER: _ClassVar[int]
    LAST_BLOCK_TIME_FIELD_NUMBER: _ClassVar[int]
    NEXT_VALIDATORS_FIELD_NUMBER: _ClassVar[int]
    VALIDATORS_FIELD_NUMBER: _ClassVar[int]
    LAST_VALIDATORS_FIELD_NUMBER: _ClassVar[int]
    LAST_HEIGHT_VALIDATORS_CHANGED_FIELD_NUMBER: _ClassVar[int]
    CONSENSUS_PARAMS_FIELD_NUMBER: _ClassVar[int]
    LAST_HEIGHT_CONSENSUS_PARAMS_CHANGED_FIELD_NUMBER: _ClassVar[int]
    LAST_RESULTS_HASH_FIELD_NUMBER: _ClassVar[int]
    APP_HASH_FIELD_NUMBER: _ClassVar[int]
    version: Version
    chain_id: str
    initial_height: int
    last_block_height: int
    last_block_id: _types_pb2_1.BlockID
    last_block_time: _timestamp_pb2.Timestamp
    next_validators: _validator_pb2.ValidatorSet
    validators: _validator_pb2.ValidatorSet
    last_validators: _validator_pb2.ValidatorSet
    last_height_validators_changed: int
    consensus_params: _params_pb2.ConsensusParams
    last_height_consensus_params_changed: int
    last_results_hash: bytes
    app_hash: bytes
    def __init__(self, version: _Optional[_Union[Version, _Mapping]] = ..., chain_id: _Optional[str] = ..., initial_height: _Optional[int] = ..., last_block_height: _Optional[int] = ..., last_block_id: _Optional[_Union[_types_pb2_1.BlockID, _Mapping]] = ..., last_block_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., next_validators: _Optional[_Union[_validator_pb2.ValidatorSet, _Mapping]] = ..., validators: _Optional[_Union[_validator_pb2.ValidatorSet, _Mapping]] = ..., last_validators: _Optional[_Union[_validator_pb2.ValidatorSet, _Mapping]] = ..., last_height_validators_changed: _Optional[int] = ..., consensus_params: _Optional[_Union[_params_pb2.ConsensusParams, _Mapping]] = ..., last_height_consensus_params_changed: _Optional[int] = ..., last_results_hash: _Optional[bytes] = ..., app_hash: _Optional[bytes] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: neurion/sanctum/query.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'neurion/sanctum/query.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from amino import amino_pb2 as amino_dot_amino__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from neurion.sanctum import params_pb2 as neurion_dot_sanctum_dot_params__pb2
from neurion.sanctum import dataset_application_pb2 as neurion_dot_sanctum_dot_dataset__application__pb2
from neurion.sanctum import dataset_usage_request_pb2 as neurion_dot_sanctum_dot_dataset__usage__request__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bneurion/sanctum/query.proto\x12\x0fneurion.sanctum\x1a\x11\x61mino/amino.proto\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a\x1cneurion/sanctum/params.proto\x1a)neurion/sanctum/dataset_application.proto\x1a+neurion/sanctum/dataset_usage_request.proto\"\x14\n\x12QueryParamsRequest\"I\n\x13QueryParamsResponse\x12\x32\n\x06params\x18\x01 \x01(\x0b\x32\x17.neurion.sanctum.ParamsB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"A\n QueryGetAvailableDatasetsRequest\x12\x0e\n\x06offset\x18\x01 \x01(\x04\x12\r\n\x05limit\x18\x02 \x01(\x04\"\xa2\x01\n!QueryGetAvailableDatasetsResponse\x12@\n\x08\x64\x61tasets\x18\x01 \x03(\x0b\x32#.neurion.sanctum.DatasetApplicationB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"&\n$QueryGetApprovedUsageRequestsRequest\"j\n%QueryGetApprovedUsageRequestsResponse\x12\x41\n\x08requests\x18\x01 \x03(\x0b\x32$.neurion.sanctum.DatasetUsageRequestB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"%\n\x15QueryGetRewardRequest\x12\x0c\n\x04user\x18\x01 \x01(\t\"(\n\x16QueryGetRewardResponse\x12\x0e\n\x06reward\x18\x01 \x01(\x04\"$\n\x14QueryGetStakeRequest\x12\x0c\n\x04user\x18\x01 \x01(\t\"&\n\x15QueryGetStakeResponse\x12\r\n\x05stake\x18\x01 \x01(\x04\" \n\x1eQueryGetPendingDatasetsRequest\"c\n\x1fQueryGetPendingDatasetsResponse\x12@\n\x08\x64\x61tasets\x18\x01 \x03(\x0b\x32#.neurion.sanctum.DatasetApplicationB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"3\n#QueryGetPendingUsageRequestsRequest\x12\x0c\n\x04user\x18\x01 \x01(\t\"i\n$QueryGetPendingUsageRequestsResponse\x12\x41\n\x08requests\x18\x01 \x03(\x0b\x32$.neurion.sanctum.DatasetUsageRequestB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"$\n\x16QueryGetDatasetRequest\x12\n\n\x02id\x18\x01 \x01(\x04\"Z\n\x17QueryGetDatasetResponse\x12?\n\x07\x64\x61taset\x18\x01 \x01(\x0b\x32#.neurion.sanctum.DatasetApplicationB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\")\n\x1bQueryGetUsageRequestRequest\x12\n\n\x02id\x18\x01 \x01(\x04\"`\n\x1cQueryGetUsageRequestResponse\x12@\n\x07request\x18\x01 \x01(\x0b\x32$.neurion.sanctum.DatasetUsageRequestB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"[\n&QueryGetUsageRequestsForDatasetRequest\x12\x12\n\ndataset_id\x18\x01 \x01(\x04\x12\x0e\n\x06offset\x18\x02 \x01(\x04\x12\r\n\x05limit\x18\x03 \x01(\x04\"\xa9\x01\n\'QueryGetUsageRequestsForDatasetResponse\x12\x41\n\x08requests\x18\x01 \x03(\x0b\x32$.neurion.sanctum.DatasetUsageRequestB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"R\n#QueryGetUsageRequestsForUserRequest\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\x02 \x01(\x04\x12\r\n\x05limit\x18\x03 \x01(\x04\"\xa6\x01\n$QueryGetUsageRequestsForUserResponse\x12\x41\n\x08requests\x18\x01 \x03(\x0b\x32$.neurion.sanctum.DatasetUsageRequestB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"M\n\x1eQueryGetDatasetsForUserRequest\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\x02 \x01(\x04\x12\r\n\x05limit\x18\x03 \x01(\x04\"\xa0\x01\n\x1fQueryGetDatasetsForUserResponse\x12@\n\x08\x64\x61tasets\x18\x01 \x03(\x0b\x32#.neurion.sanctum.DatasetApplicationB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse2\xa1\x10\n\x05Query\x12t\n\x06Params\x12#.neurion.sanctum.QueryParamsRequest\x1a$.neurion.sanctum.QueryParamsResponse\"\x1f\x82\xd3\xe4\x93\x02\x19\x12\x17/neurion/sanctum/params\x12\xae\x01\n\x14GetAvailableDatasets\x12\x31.neurion.sanctum.QueryGetAvailableDatasetsRequest\x1a\x32.neurion.sanctum.QueryGetAvailableDatasetsResponse\"/\x82\xd3\xe4\x93\x02)\x12\'/neurion/sanctum/get_available_datasets\x12\xbf\x01\n\x18GetApprovedUsageRequests\x12\x35.neurion.sanctum.QueryGetApprovedUsageRequestsRequest\x1a\x36.neurion.sanctum.QueryGetApprovedUsageRequestsResponse\"4\x82\xd3\xe4\x93\x02.\x12,/neurion/sanctum/get_approved_usage_requests\x12\x88\x01\n\tGetReward\x12&.neurion.sanctum.QueryGetRewardRequest\x1a\'.neurion.sanctum.QueryGetRewardResponse\"*\x82\xd3\xe4\x93\x02$\x12\"/neurion/sanctum/get_reward/{user}\x12\x84\x01\n\x08GetStake\x12%.neurion.sanctum.QueryGetStakeRequest\x1a&.neurion.sanctum.QueryGetStakeResponse\")\x82\xd3\xe4\x93\x02#\x12!/neurion/sanctum/get_stake/{user}\x12\xa6\x01\n\x12GetPendingDatasets\x12/.neurion.sanctum.QueryGetPendingDatasetsRequest\x1a\x30.neurion.sanctum.QueryGetPendingDatasetsResponse\"-\x82\xd3\xe4\x93\x02\'\x12%/neurion/sanctum/get_pending_datasets\x12\xc2\x01\n\x17GetPendingUsageRequests\x12\x34.neurion.sanctum.QueryGetPendingUsageRequestsRequest\x1a\x35.neurion.sanctum.QueryGetPendingUsageRequestsResponse\":\x82\xd3\xe4\x93\x02\x34\x12\x32/neurion/sanctum/get_pending_usage_requests/{user}\x12\x8a\x01\n\nGetDataset\x12\'.neurion.sanctum.QueryGetDatasetRequest\x1a(.neurion.sanctum.QueryGetDatasetResponse\")\x82\xd3\xe4\x93\x02#\x12!/neurion/sanctum/get_dataset/{id}\x12\x9f\x01\n\x0fGetUsageRequest\x12,.neurion.sanctum.QueryGetUsageRequestRequest\x1a-.neurion.sanctum.QueryGetUsageRequestResponse\"/\x82\xd3\xe4\x93\x02)\x12\'/neurion/sanctum/get_usage_request/{id}\x12\xe6\x01\n\x1aGetUsageRequestsForDataset\x12\x37.neurion.sanctum.QueryGetUsageRequestsForDatasetRequest\x1a\x38.neurion.sanctum.QueryGetUsageRequestsForDatasetResponse\"U\x82\xd3\xe4\x93\x02O\x12M/neurion/sanctum/get_usage_requests_for_dataset/{dataset_id}/{offset}/{limit}\x12\xd4\x01\n\x17GetUsageRequestsForUser\x12\x34.neurion.sanctum.QueryGetUsageRequestsForUserRequest\x1a\x35.neurion.sanctum.QueryGetUsageRequestsForUserResponse\"L\x82\xd3\xe4\x93\x02\x46\x12\x44/neurion/sanctum/get_usage_requests_for_user/{user}/{offset}/{limit}\x12\xbf\x01\n\x12GetDatasetsForUser\x12/.neurion.sanctum.QueryGetDatasetsForUserRequest\x1a\x30.neurion.sanctum.QueryGetDatasetsForUserResponse\"F\x82\xd3\xe4\x93\x02@\x12>/neurion/sanctum/get_datasets_for_user/{user}/{offset}/{limit}B\x19Z\x17neurion/x/sanctum/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'neurion.sanctum.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\027neurion/x/sanctum/types'
  _globals['_QUERYPARAMSRESPONSE'].fields_by_name['params']._loaded_options = None
  _globals['_QUERYPARAMSRESPONSE'].fields_by_name['params']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYGETAVAILABLEDATASETSRESPONSE'].fields_by_name['datasets']._loaded_options = None
  _globals['_QUERYGETAVAILABLEDATASETSRESPONSE'].fields_by_name['datasets']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYGETAPPROVEDUSAGEREQUESTSRESPONSE'].fields_by_name['requests']._loaded_options = None
  _globals['_QUERYGETAPPROVEDUSAGEREQUESTSRESPONSE'].fields_by_name['requests']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYGETPENDINGDATASETSRESPONSE'].fields_by_name['datasets']._loaded_options = None
  _globals['_QUERYGETPENDINGDATASETSRESPONSE'].fields_by_name['datasets']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYGETPENDINGUSAGEREQUESTSRESPONSE'].fields_by_name['requests']._loaded_options = None
  _globals['_QUERYGETPENDINGUSAGEREQUESTSRESPONSE'].fields_by_name['requests']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYGETDATASETRESPONSE'].fields_by_name['dataset']._loaded_options = None
  _globals['_QUERYGETDATASETRESPONSE'].fields_by_name['dataset']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYGETUSAGEREQUESTRESPONSE'].fields_by_name['request']._loaded_options = None
  _globals['_QUERYGETUSAGEREQUESTRESPONSE'].fields_by_name['request']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYGETUSAGEREQUESTSFORDATASETRESPONSE'].fields_by_name['requests']._loaded_options = None
  _globals['_QUERYGETUSAGEREQUESTSFORDATASETRESPONSE'].fields_by_name['requests']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYGETUSAGEREQUESTSFORUSERRESPONSE'].fields_by_name['requests']._loaded_options = None
  _globals['_QUERYGETUSAGEREQUESTSFORUSERRESPONSE'].fields_by_name['requests']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYGETDATASETSFORUSERRESPONSE'].fields_by_name['datasets']._loaded_options = None
  _globals['_QUERYGETDATASETSFORUSERRESPONSE'].fields_by_name['datasets']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERY'].methods_by_name['Params']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Params']._serialized_options = b'\202\323\344\223\002\031\022\027/neurion/sanctum/params'
  _globals['_QUERY'].methods_by_name['GetAvailableDatasets']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetAvailableDatasets']._serialized_options = b'\202\323\344\223\002)\022\'/neurion/sanctum/get_available_datasets'
  _globals['_QUERY'].methods_by_name['GetApprovedUsageRequests']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetApprovedUsageRequests']._serialized_options = b'\202\323\344\223\002.\022,/neurion/sanctum/get_approved_usage_requests'
  _globals['_QUERY'].methods_by_name['GetReward']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetReward']._serialized_options = b'\202\323\344\223\002$\022\"/neurion/sanctum/get_reward/{user}'
  _globals['_QUERY'].methods_by_name['GetStake']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetStake']._serialized_options = b'\202\323\344\223\002#\022!/neurion/sanctum/get_stake/{user}'
  _globals['_QUERY'].methods_by_name['GetPendingDatasets']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetPendingDatasets']._serialized_options = b'\202\323\344\223\002\'\022%/neurion/sanctum/get_pending_datasets'
  _globals['_QUERY'].methods_by_name['GetPendingUsageRequests']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetPendingUsageRequests']._serialized_options = b'\202\323\344\223\0024\0222/neurion/sanctum/get_pending_usage_requests/{user}'
  _globals['_QUERY'].methods_by_name['GetDataset']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetDataset']._serialized_options = b'\202\323\344\223\002#\022!/neurion/sanctum/get_dataset/{id}'
  _globals['_QUERY'].methods_by_name['GetUsageRequest']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetUsageRequest']._serialized_options = b'\202\323\344\223\002)\022\'/neurion/sanctum/get_usage_request/{id}'
  _globals['_QUERY'].methods_by_name['GetUsageRequestsForDataset']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetUsageRequestsForDataset']._serialized_options = b'\202\323\344\223\002O\022M/neurion/sanctum/get_usage_requests_for_dataset/{dataset_id}/{offset}/{limit}'
  _globals['_QUERY'].methods_by_name['GetUsageRequestsForUser']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetUsageRequestsForUser']._serialized_options = b'\202\323\344\223\002F\022D/neurion/sanctum/get_usage_requests_for_user/{user}/{offset}/{limit}'
  _globals['_QUERY'].methods_by_name['GetDatasetsForUser']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetDatasetsForUser']._serialized_options = b'\202\323\344\223\002@\022>/neurion/sanctum/get_datasets_for_user/{user}/{offset}/{limit}'
  _globals['_QUERYPARAMSREQUEST']._serialized_start=281
  _globals['_QUERYPARAMSREQUEST']._serialized_end=301
  _globals['_QUERYPARAMSRESPONSE']._serialized_start=303
  _globals['_QUERYPARAMSRESPONSE']._serialized_end=376
  _globals['_QUERYGETAVAILABLEDATASETSREQUEST']._serialized_start=378
  _globals['_QUERYGETAVAILABLEDATASETSREQUEST']._serialized_end=443
  _globals['_QUERYGETAVAILABLEDATASETSRESPONSE']._serialized_start=446
  _globals['_QUERYGETAVAILABLEDATASETSRESPONSE']._serialized_end=608
  _globals['_QUERYGETAPPROVEDUSAGEREQUESTSREQUEST']._serialized_start=610
  _globals['_QUERYGETAPPROVEDUSAGEREQUESTSREQUEST']._serialized_end=648
  _globals['_QUERYGETAPPROVEDUSAGEREQUESTSRESPONSE']._serialized_start=650
  _globals['_QUERYGETAPPROVEDUSAGEREQUESTSRESPONSE']._serialized_end=756
  _globals['_QUERYGETREWARDREQUEST']._serialized_start=758
  _globals['_QUERYGETREWARDREQUEST']._serialized_end=795
  _globals['_QUERYGETREWARDRESPONSE']._serialized_start=797
  _globals['_QUERYGETREWARDRESPONSE']._serialized_end=837
  _globals['_QUERYGETSTAKEREQUEST']._serialized_start=839
  _globals['_QUERYGETSTAKEREQUEST']._serialized_end=875
  _globals['_QUERYGETSTAKERESPONSE']._serialized_start=877
  _globals['_QUERYGETSTAKERESPONSE']._serialized_end=915
  _globals['_QUERYGETPENDINGDATASETSREQUEST']._serialized_start=917
  _globals['_QUERYGETPENDINGDATASETSREQUEST']._serialized_end=949
  _globals['_QUERYGETPENDINGDATASETSRESPONSE']._serialized_start=951
  _globals['_QUERYGETPENDINGDATASETSRESPONSE']._serialized_end=1050
  _globals['_QUERYGETPENDINGUSAGEREQUESTSREQUEST']._serialized_start=1052
  _globals['_QUERYGETPENDINGUSAGEREQUESTSREQUEST']._serialized_end=1103
  _globals['_QUERYGETPENDINGUSAGEREQUESTSRESPONSE']._serialized_start=1105
  _globals['_QUERYGETPENDINGUSAGEREQUESTSRESPONSE']._serialized_end=1210
  _globals['_QUERYGETDATASETREQUEST']._serialized_start=1212
  _globals['_QUERYGETDATASETREQUEST']._serialized_end=1248
  _globals['_QUERYGETDATASETRESPONSE']._serialized_start=1250
  _globals['_QUERYGETDATASETRESPONSE']._serialized_end=1340
  _globals['_QUERYGETUSAGEREQUESTREQUEST']._serialized_start=1342
  _globals['_QUERYGETUSAGEREQUESTREQUEST']._serialized_end=1383
  _globals['_QUERYGETUSAGEREQUESTRESPONSE']._serialized_start=1385
  _globals['_QUERYGETUSAGEREQUESTRESPONSE']._serialized_end=1481
  _globals['_QUERYGETUSAGEREQUESTSFORDATASETREQUEST']._serialized_start=1483
  _globals['_QUERYGETUSAGEREQUESTSFORDATASETREQUEST']._serialized_end=1574
  _globals['_QUERYGETUSAGEREQUESTSFORDATASETRESPONSE']._serialized_start=1577
  _globals['_QUERYGETUSAGEREQUESTSFORDATASETRESPONSE']._serialized_end=1746
  _globals['_QUERYGETUSAGEREQUESTSFORUSERREQUEST']._serialized_start=1748
  _globals['_QUERYGETUSAGEREQUESTSFORUSERREQUEST']._serialized_end=1830
  _globals['_QUERYGETUSAGEREQUESTSFORUSERRESPONSE']._serialized_start=1833
  _globals['_QUERYGETUSAGEREQUESTSFORUSERRESPONSE']._serialized_end=1999
  _globals['_QUERYGETDATASETSFORUSERREQUEST']._serialized_start=2001
  _globals['_QUERYGETDATASETSFORUSERREQUEST']._serialized_end=2078
  _globals['_QUERYGETDATASETSFORUSERRESPONSE']._serialized_start=2081
  _globals['_QUERYGETDATASETSFORUSERRESPONSE']._serialized_end=2241
  _globals['_QUERY']._serialized_start=2244
  _globals['_QUERY']._serialized_end=4325
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: tendermint/abci/types.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'tendermint/abci/types.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from tendermint.crypto import proof_pb2 as tendermint_dot_crypto_dot_proof__pb2
from tendermint.types import types_pb2 as tendermint_dot_types_dot_types__pb2
from tendermint.crypto import keys_pb2 as tendermint_dot_crypto_dot_keys__pb2
from tendermint.types import params_pb2 as tendermint_dot_types_dot_params__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1btendermint/abci/types.proto\x12\x0ftendermint.abci\x1a\x1dtendermint/crypto/proof.proto\x1a\x1ctendermint/types/types.proto\x1a\x1ctendermint/crypto/keys.proto\x1a\x1dtendermint/types/params.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x14gogoproto/gogo.proto\"\xea\x06\n\x07Request\x12,\n\x04\x65\x63ho\x18\x01 \x01(\x0b\x32\x1c.tendermint.abci.RequestEchoH\x00\x12.\n\x05\x66lush\x18\x02 \x01(\x0b\x32\x1d.tendermint.abci.RequestFlushH\x00\x12,\n\x04info\x18\x03 \x01(\x0b\x32\x1c.tendermint.abci.RequestInfoH\x00\x12\x37\n\nset_option\x18\x04 \x01(\x0b\x32!.tendermint.abci.RequestSetOptionH\x00\x12\x37\n\ninit_chain\x18\x05 \x01(\x0b\x32!.tendermint.abci.RequestInitChainH\x00\x12.\n\x05query\x18\x06 \x01(\x0b\x32\x1d.tendermint.abci.RequestQueryH\x00\x12\x39\n\x0b\x62\x65gin_block\x18\x07 \x01(\x0b\x32\".tendermint.abci.RequestBeginBlockH\x00\x12\x33\n\x08\x63heck_tx\x18\x08 \x01(\x0b\x32\x1f.tendermint.abci.RequestCheckTxH\x00\x12\x37\n\ndeliver_tx\x18\t \x01(\x0b\x32!.tendermint.abci.RequestDeliverTxH\x00\x12\x35\n\tend_block\x18\n \x01(\x0b\x32 .tendermint.abci.RequestEndBlockH\x00\x12\x30\n\x06\x63ommit\x18\x0b \x01(\x0b\x32\x1e.tendermint.abci.RequestCommitH\x00\x12?\n\x0elist_snapshots\x18\x0c \x01(\x0b\x32%.tendermint.abci.RequestListSnapshotsH\x00\x12?\n\x0eoffer_snapshot\x18\r \x01(\x0b\x32%.tendermint.abci.RequestOfferSnapshotH\x00\x12H\n\x13load_snapshot_chunk\x18\x0e \x01(\x0b\x32).tendermint.abci.RequestLoadSnapshotChunkH\x00\x12J\n\x14\x61pply_snapshot_chunk\x18\x0f \x01(\x0b\x32*.tendermint.abci.RequestApplySnapshotChunkH\x00\x42\x07\n\x05value\"\x1e\n\x0bRequestEcho\x12\x0f\n\x07message\x18\x01 \x01(\t\"\x0e\n\x0cRequestFlush\"J\n\x0bRequestInfo\x12\x0f\n\x07version\x18\x01 \x01(\t\x12\x15\n\rblock_version\x18\x02 \x01(\x04\x12\x13\n\x0bp2p_version\x18\x03 \x01(\x04\".\n\x10RequestSetOption\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"\x81\x02\n\x10RequestInitChain\x12\x32\n\x04time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01\x12\x10\n\x08\x63hain_id\x18\x02 \x01(\t\x12:\n\x10\x63onsensus_params\x18\x03 \x01(\x0b\x32 .tendermint.abci.ConsensusParams\x12:\n\nvalidators\x18\x04 \x03(\x0b\x32 .tendermint.abci.ValidatorUpdateB\x04\xc8\xde\x1f\x00\x12\x17\n\x0f\x61pp_state_bytes\x18\x05 \x01(\x0c\x12\x16\n\x0einitial_height\x18\x06 \x01(\x03\"I\n\x0cRequestQuery\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x0e\n\x06height\x18\x03 \x01(\x03\x12\r\n\x05prove\x18\x04 \x01(\x08\"\xd1\x01\n\x11RequestBeginBlock\x12\x0c\n\x04hash\x18\x01 \x01(\x0c\x12.\n\x06header\x18\x02 \x01(\x0b\x32\x18.tendermint.types.HeaderB\x04\xc8\xde\x1f\x00\x12?\n\x10last_commit_info\x18\x03 \x01(\x0b\x32\x1f.tendermint.abci.LastCommitInfoB\x04\xc8\xde\x1f\x00\x12=\n\x14\x62yzantine_validators\x18\x04 \x03(\x0b\x32\x19.tendermint.abci.EvidenceB\x04\xc8\xde\x1f\x00\"H\n\x0eRequestCheckTx\x12\n\n\x02tx\x18\x01 \x01(\x0c\x12*\n\x04type\x18\x02 \x01(\x0e\x32\x1c.tendermint.abci.CheckTxType\"\x1e\n\x10RequestDeliverTx\x12\n\n\x02tx\x18\x01 \x01(\x0c\"!\n\x0fRequestEndBlock\x12\x0e\n\x06height\x18\x01 \x01(\x03\"\x0f\n\rRequestCommit\"\x16\n\x14RequestListSnapshots\"U\n\x14RequestOfferSnapshot\x12+\n\x08snapshot\x18\x01 \x01(\x0b\x32\x19.tendermint.abci.Snapshot\x12\x10\n\x08\x61pp_hash\x18\x02 \x01(\x0c\"I\n\x18RequestLoadSnapshotChunk\x12\x0e\n\x06height\x18\x01 \x01(\x04\x12\x0e\n\x06\x66ormat\x18\x02 \x01(\r\x12\r\n\x05\x63hunk\x18\x03 \x01(\r\"I\n\x19RequestApplySnapshotChunk\x12\r\n\x05index\x18\x01 \x01(\r\x12\r\n\x05\x63hunk\x18\x02 \x01(\x0c\x12\x0e\n\x06sender\x18\x03 \x01(\t\"\xb3\x07\n\x08Response\x12\x37\n\texception\x18\x01 \x01(\x0b\x32\".tendermint.abci.ResponseExceptionH\x00\x12-\n\x04\x65\x63ho\x18\x02 \x01(\x0b\x32\x1d.tendermint.abci.ResponseEchoH\x00\x12/\n\x05\x66lush\x18\x03 \x01(\x0b\x32\x1e.tendermint.abci.ResponseFlushH\x00\x12-\n\x04info\x18\x04 \x01(\x0b\x32\x1d.tendermint.abci.ResponseInfoH\x00\x12\x38\n\nset_option\x18\x05 \x01(\x0b\x32\".tendermint.abci.ResponseSetOptionH\x00\x12\x38\n\ninit_chain\x18\x06 \x01(\x0b\x32\".tendermint.abci.ResponseInitChainH\x00\x12/\n\x05query\x18\x07 \x01(\x0b\x32\x1e.tendermint.abci.ResponseQueryH\x00\x12:\n\x0b\x62\x65gin_block\x18\x08 \x01(\x0b\x32#.tendermint.abci.ResponseBeginBlockH\x00\x12\x34\n\x08\x63heck_tx\x18\t \x01(\x0b\x32 .tendermint.abci.ResponseCheckTxH\x00\x12\x38\n\ndeliver_tx\x18\n \x01(\x0b\x32\".tendermint.abci.ResponseDeliverTxH\x00\x12\x36\n\tend_block\x18\x0b \x01(\x0b\x32!.tendermint.abci.ResponseEndBlockH\x00\x12\x31\n\x06\x63ommit\x18\x0c \x01(\x0b\x32\x1f.tendermint.abci.ResponseCommitH\x00\x12@\n\x0elist_snapshots\x18\r \x01(\x0b\x32&.tendermint.abci.ResponseListSnapshotsH\x00\x12@\n\x0eoffer_snapshot\x18\x0e \x01(\x0b\x32&.tendermint.abci.ResponseOfferSnapshotH\x00\x12I\n\x13load_snapshot_chunk\x18\x0f \x01(\x0b\x32*.tendermint.abci.ResponseLoadSnapshotChunkH\x00\x12K\n\x14\x61pply_snapshot_chunk\x18\x10 \x01(\x0b\x32+.tendermint.abci.ResponseApplySnapshotChunkH\x00\x42\x07\n\x05value\"\"\n\x11ResponseException\x12\r\n\x05\x65rror\x18\x01 \x01(\t\"\x1f\n\x0cResponseEcho\x12\x0f\n\x07message\x18\x01 \x01(\t\"\x0f\n\rResponseFlush\"z\n\x0cResponseInfo\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x13\n\x0b\x61pp_version\x18\x03 \x01(\x04\x12\x19\n\x11last_block_height\x18\x04 \x01(\x03\x12\x1b\n\x13last_block_app_hash\x18\x05 \x01(\x0c\"<\n\x11ResponseSetOption\x12\x0c\n\x04\x63ode\x18\x01 \x01(\r\x12\x0b\n\x03log\x18\x03 \x01(\t\x12\x0c\n\x04info\x18\x04 \x01(\t\"\x9d\x01\n\x11ResponseInitChain\x12:\n\x10\x63onsensus_params\x18\x01 \x01(\x0b\x32 .tendermint.abci.ConsensusParams\x12:\n\nvalidators\x18\x02 \x03(\x0b\x32 .tendermint.abci.ValidatorUpdateB\x04\xc8\xde\x1f\x00\x12\x10\n\x08\x61pp_hash\x18\x03 \x01(\x0c\"\xb6\x01\n\rResponseQuery\x12\x0c\n\x04\x63ode\x18\x01 \x01(\r\x12\x0b\n\x03log\x18\x03 \x01(\t\x12\x0c\n\x04info\x18\x04 \x01(\t\x12\r\n\x05index\x18\x05 \x01(\x03\x12\x0b\n\x03key\x18\x06 \x01(\x0c\x12\r\n\x05value\x18\x07 \x01(\x0c\x12.\n\tproof_ops\x18\x08 \x01(\x0b\x32\x1b.tendermint.crypto.ProofOps\x12\x0e\n\x06height\x18\t \x01(\x03\x12\x11\n\tcodespace\x18\n \x01(\t\"V\n\x12ResponseBeginBlock\x12@\n\x06\x65vents\x18\x01 \x03(\x0b\x32\x16.tendermint.abci.EventB\x18\xc8\xde\x1f\x00\xea\xde\x1f\x10\x65vents,omitempty\"\xd9\x01\n\x0fResponseCheckTx\x12\x0c\n\x04\x63ode\x18\x01 \x01(\r\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\x12\x0b\n\x03log\x18\x03 \x01(\t\x12\x0c\n\x04info\x18\x04 \x01(\t\x12\x1e\n\ngas_wanted\x18\x05 \x01(\x03R\ngas_wanted\x12\x1a\n\x08gas_used\x18\x06 \x01(\x03R\x08gas_used\x12@\n\x06\x65vents\x18\x07 \x03(\x0b\x32\x16.tendermint.abci.EventB\x18\xc8\xde\x1f\x00\xea\xde\x1f\x10\x65vents,omitempty\x12\x11\n\tcodespace\x18\x08 \x01(\t\"\xdb\x01\n\x11ResponseDeliverTx\x12\x0c\n\x04\x63ode\x18\x01 \x01(\r\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\x12\x0b\n\x03log\x18\x03 \x01(\t\x12\x0c\n\x04info\x18\x04 \x01(\t\x12\x1e\n\ngas_wanted\x18\x05 \x01(\x03R\ngas_wanted\x12\x1a\n\x08gas_used\x18\x06 \x01(\x03R\x08gas_used\x12@\n\x06\x65vents\x18\x07 \x03(\x0b\x32\x16.tendermint.abci.EventB\x18\xc8\xde\x1f\x00\xea\xde\x1f\x10\x65vents,omitempty\x12\x11\n\tcodespace\x18\x08 \x01(\t\"\xda\x01\n\x10ResponseEndBlock\x12\x41\n\x11validator_updates\x18\x01 \x03(\x0b\x32 .tendermint.abci.ValidatorUpdateB\x04\xc8\xde\x1f\x00\x12\x41\n\x17\x63onsensus_param_updates\x18\x02 \x01(\x0b\x32 .tendermint.abci.ConsensusParams\x12@\n\x06\x65vents\x18\x03 \x03(\x0b\x32\x16.tendermint.abci.EventB\x18\xc8\xde\x1f\x00\xea\xde\x1f\x10\x65vents,omitempty\"5\n\x0eResponseCommit\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\x12\x15\n\rretain_height\x18\x03 \x01(\x03\"E\n\x15ResponseListSnapshots\x12,\n\tsnapshots\x18\x01 \x03(\x0b\x32\x19.tendermint.abci.Snapshot\"\xb6\x01\n\x15ResponseOfferSnapshot\x12=\n\x06result\x18\x01 \x01(\x0e\x32-.tendermint.abci.ResponseOfferSnapshot.Result\"^\n\x06Result\x12\x0b\n\x07UNKNOWN\x10\x00\x12\n\n\x06\x41\x43\x43\x45PT\x10\x01\x12\t\n\x05\x41\x42ORT\x10\x02\x12\n\n\x06REJECT\x10\x03\x12\x11\n\rREJECT_FORMAT\x10\x04\x12\x11\n\rREJECT_SENDER\x10\x05\"*\n\x19ResponseLoadSnapshotChunk\x12\r\n\x05\x63hunk\x18\x01 \x01(\x0c\"\xf2\x01\n\x1aResponseApplySnapshotChunk\x12\x42\n\x06result\x18\x01 \x01(\x0e\x32\x32.tendermint.abci.ResponseApplySnapshotChunk.Result\x12\x16\n\x0erefetch_chunks\x18\x02 \x03(\r\x12\x16\n\x0ereject_senders\x18\x03 \x03(\t\"`\n\x06Result\x12\x0b\n\x07UNKNOWN\x10\x00\x12\n\n\x06\x41\x43\x43\x45PT\x10\x01\x12\t\n\x05\x41\x42ORT\x10\x02\x12\t\n\x05RETRY\x10\x03\x12\x12\n\x0eRETRY_SNAPSHOT\x10\x04\x12\x13\n\x0fREJECT_SNAPSHOT\x10\x05\"\xda\x01\n\x0f\x43onsensusParams\x12+\n\x05\x62lock\x18\x01 \x01(\x0b\x32\x1c.tendermint.abci.BlockParams\x12\x32\n\x08\x65vidence\x18\x02 \x01(\x0b\x32 .tendermint.types.EvidenceParams\x12\x34\n\tvalidator\x18\x03 \x01(\x0b\x32!.tendermint.types.ValidatorParams\x12\x30\n\x07version\x18\x04 \x01(\x0b\x32\x1f.tendermint.types.VersionParams\"1\n\x0b\x42lockParams\x12\x11\n\tmax_bytes\x18\x01 \x01(\x03\x12\x0f\n\x07max_gas\x18\x02 \x01(\x03\"O\n\x0eLastCommitInfo\x12\r\n\x05round\x18\x01 \x01(\x05\x12.\n\x05votes\x18\x02 \x03(\x0b\x32\x19.tendermint.abci.VoteInfoB\x04\xc8\xde\x1f\x00\"h\n\x05\x45vent\x12\x0c\n\x04type\x18\x01 \x01(\t\x12Q\n\nattributes\x18\x02 \x03(\x0b\x32\x1f.tendermint.abci.EventAttributeB\x1c\xc8\xde\x1f\x00\xea\xde\x1f\x14\x61ttributes,omitempty\";\n\x0e\x45ventAttribute\x12\x0b\n\x03key\x18\x01 \x01(\x0c\x12\r\n\x05value\x18\x02 \x01(\x0c\x12\r\n\x05index\x18\x03 \x01(\x08\"o\n\x08TxResult\x12\x0e\n\x06height\x18\x01 \x01(\x03\x12\r\n\x05index\x18\x02 \x01(\r\x12\n\n\x02tx\x18\x03 \x01(\x0c\x12\x38\n\x06result\x18\x04 \x01(\x0b\x32\".tendermint.abci.ResponseDeliverTxB\x04\xc8\xde\x1f\x00\"+\n\tValidator\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\x0c\x12\r\n\x05power\x18\x03 \x01(\x03\"U\n\x0fValidatorUpdate\x12\x33\n\x07pub_key\x18\x01 \x01(\x0b\x32\x1c.tendermint.crypto.PublicKeyB\x04\xc8\xde\x1f\x00\x12\r\n\x05power\x18\x02 \x01(\x03\"Z\n\x08VoteInfo\x12\x33\n\tvalidator\x18\x01 \x01(\x0b\x32\x1a.tendermint.abci.ValidatorB\x04\xc8\xde\x1f\x00\x12\x19\n\x11signed_last_block\x18\x02 \x01(\x08\"\xcc\x01\n\x08\x45vidence\x12+\n\x04type\x18\x01 \x01(\x0e\x32\x1d.tendermint.abci.EvidenceType\x12\x33\n\tvalidator\x18\x02 \x01(\x0b\x32\x1a.tendermint.abci.ValidatorB\x04\xc8\xde\x1f\x00\x12\x0e\n\x06height\x18\x03 \x01(\x03\x12\x32\n\x04time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01\x12\x1a\n\x12total_voting_power\x18\x05 \x01(\x03\"Z\n\x08Snapshot\x12\x0e\n\x06height\x18\x01 \x01(\x04\x12\x0e\n\x06\x66ormat\x18\x02 \x01(\r\x12\x0e\n\x06\x63hunks\x18\x03 \x01(\r\x12\x0c\n\x04hash\x18\x04 \x01(\x0c\x12\x10\n\x08metadata\x18\x05 \x01(\x0c*9\n\x0b\x43heckTxType\x12\x10\n\x03NEW\x10\x00\x1a\x07\x8a\x9d \x03New\x12\x18\n\x07RECHECK\x10\x01\x1a\x0b\x8a\x9d \x07Recheck*H\n\x0c\x45videnceType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x12\n\x0e\x44UPLICATE_VOTE\x10\x01\x12\x17\n\x13LIGHT_CLIENT_ATTACK\x10\x02\x32\x83\n\n\x0f\x41\x42\x43IApplication\x12\x43\n\x04\x45\x63ho\x12\x1c.tendermint.abci.RequestEcho\x1a\x1d.tendermint.abci.ResponseEcho\x12\x46\n\x05\x46lush\x12\x1d.tendermint.abci.RequestFlush\x1a\x1e.tendermint.abci.ResponseFlush\x12\x43\n\x04Info\x12\x1c.tendermint.abci.RequestInfo\x1a\x1d.tendermint.abci.ResponseInfo\x12R\n\tSetOption\x12!.tendermint.abci.RequestSetOption\x1a\".tendermint.abci.ResponseSetOption\x12R\n\tDeliverTx\x12!.tendermint.abci.RequestDeliverTx\x1a\".tendermint.abci.ResponseDeliverTx\x12L\n\x07\x43heckTx\x12\x1f.tendermint.abci.RequestCheckTx\x1a .tendermint.abci.ResponseCheckTx\x12\x46\n\x05Query\x12\x1d.tendermint.abci.RequestQuery\x1a\x1e.tendermint.abci.ResponseQuery\x12I\n\x06\x43ommit\x12\x1e.tendermint.abci.RequestCommit\x1a\x1f.tendermint.abci.ResponseCommit\x12R\n\tInitChain\x12!.tendermint.abci.RequestInitChain\x1a\".tendermint.abci.ResponseInitChain\x12U\n\nBeginBlock\x12\".tendermint.abci.RequestBeginBlock\x1a#.tendermint.abci.ResponseBeginBlock\x12O\n\x08\x45ndBlock\x12 .tendermint.abci.RequestEndBlock\x1a!.tendermint.abci.ResponseEndBlock\x12^\n\rListSnapshots\x12%.tendermint.abci.RequestListSnapshots\x1a&.tendermint.abci.ResponseListSnapshots\x12^\n\rOfferSnapshot\x12%.tendermint.abci.RequestOfferSnapshot\x1a&.tendermint.abci.ResponseOfferSnapshot\x12j\n\x11LoadSnapshotChunk\x12).tendermint.abci.RequestLoadSnapshotChunk\x1a*.tendermint.abci.ResponseLoadSnapshotChunk\x12m\n\x12\x41pplySnapshotChunk\x12*.tendermint.abci.RequestApplySnapshotChunk\x1a+.tendermint.abci.ResponseApplySnapshotChunkB-Z+github.com/tendermint/tendermint/abci/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tendermint.abci.types_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z+github.com/tendermint/tendermint/abci/types'
  _globals['_CHECKTXTYPE'].values_by_name["NEW"]._loaded_options = None
  _globals['_CHECKTXTYPE'].values_by_name["NEW"]._serialized_options = b'\212\235 \003New'
  _globals['_CHECKTXTYPE'].values_by_name["RECHECK"]._loaded_options = None
  _globals['_CHECKTXTYPE'].values_by_name["RECHECK"]._serialized_options = b'\212\235 \007Recheck'
  _globals['_REQUESTINITCHAIN'].fields_by_name['time']._loaded_options = None
  _globals['_REQUESTINITCHAIN'].fields_by_name['time']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _globals['_REQUESTINITCHAIN'].fields_by_name['validators']._loaded_options = None
  _globals['_REQUESTINITCHAIN'].fields_by_name['validators']._serialized_options = b'\310\336\037\000'
  _globals['_REQUESTBEGINBLOCK'].fields_by_name['header']._loaded_options = None
  _globals['_REQUESTBEGINBLOCK'].fields_by_name['header']._serialized_options = b'\310\336\037\000'
  _globals['_REQUESTBEGINBLOCK'].fields_by_name['last_commit_info']._loaded_options = None
  _globals['_REQUESTBEGINBLOCK'].fields_by_name['last_commit_info']._serialized_options = b'\310\336\037\000'
  _globals['_REQUESTBEGINBLOCK'].fields_by_name['byzantine_validators']._loaded_options = None
  _globals['_REQUESTBEGINBLOCK'].fields_by_name['byzantine_validators']._serialized_options = b'\310\336\037\000'
  _globals['_RESPONSEINITCHAIN'].fields_by_name['validators']._loaded_options = None
  _globals['_RESPONSEINITCHAIN'].fields_by_name['validators']._serialized_options = b'\310\336\037\000'
  _globals['_RESPONSEBEGINBLOCK'].fields_by_name['events']._loaded_options = None
  _globals['_RESPONSEBEGINBLOCK'].fields_by_name['events']._serialized_options = b'\310\336\037\000\352\336\037\020events,omitempty'
  _globals['_RESPONSECHECKTX'].fields_by_name['events']._loaded_options = None
  _globals['_RESPONSECHECKTX'].fields_by_name['events']._serialized_options = b'\310\336\037\000\352\336\037\020events,omitempty'
  _globals['_RESPONSEDELIVERTX'].fields_by_name['events']._loaded_options = None
  _globals['_RESPONSEDELIVERTX'].fields_by_name['events']._serialized_options = b'\310\336\037\000\352\336\037\020events,omitempty'
  _globals['_RESPONSEENDBLOCK'].fields_by_name['validator_updates']._loaded_options = None
  _globals['_RESPONSEENDBLOCK'].fields_by_name['validator_updates']._serialized_options = b'\310\336\037\000'
  _globals['_RESPONSEENDBLOCK'].fields_by_name['events']._loaded_options = None
  _globals['_RESPONSEENDBLOCK'].fields_by_name['events']._serialized_options = b'\310\336\037\000\352\336\037\020events,omitempty'
  _globals['_LASTCOMMITINFO'].fields_by_name['votes']._loaded_options = None
  _globals['_LASTCOMMITINFO'].fields_by_name['votes']._serialized_options = b'\310\336\037\000'
  _globals['_EVENT'].fields_by_name['attributes']._loaded_options = None
  _globals['_EVENT'].fields_by_name['attributes']._serialized_options = b'\310\336\037\000\352\336\037\024attributes,omitempty'
  _globals['_TXRESULT'].fields_by_name['result']._loaded_options = None
  _globals['_TXRESULT'].fields_by_name['result']._serialized_options = b'\310\336\037\000'
  _globals['_VALIDATORUPDATE'].fields_by_name['pub_key']._loaded_options = None
  _globals['_VALIDATORUPDATE'].fields_by_name['pub_key']._serialized_options = b'\310\336\037\000'
  _globals['_VOTEINFO'].fields_by_name['validator']._loaded_options = None
  _globals['_VOTEINFO'].fields_by_name['validator']._serialized_options = b'\310\336\037\000'
  _globals['_EVIDENCE'].fields_by_name['validator']._loaded_options = None
  _globals['_EVIDENCE'].fields_by_name['validator']._serialized_options = b'\310\336\037\000'
  _globals['_EVIDENCE'].fields_by_name['time']._loaded_options = None
  _globals['_EVIDENCE'].fields_by_name['time']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _globals['_CHECKTXTYPE']._serialized_start=6314
  _globals['_CHECKTXTYPE']._serialized_end=6371
  _globals['_EVIDENCETYPE']._serialized_start=6373
  _globals['_EVIDENCETYPE']._serialized_end=6445
  _globals['_REQUEST']._serialized_start=226
  _globals['_REQUEST']._serialized_end=1100
  _globals['_REQUESTECHO']._serialized_start=1102
  _globals['_REQUESTECHO']._serialized_end=1132
  _globals['_REQUESTFLUSH']._serialized_start=1134
  _globals['_REQUESTFLUSH']._serialized_end=1148
  _globals['_REQUESTINFO']._serialized_start=1150
  _globals['_REQUESTINFO']._serialized_end=1224
  _globals['_REQUESTSETOPTION']._serialized_start=1226
  _globals['_REQUESTSETOPTION']._serialized_end=1272
  _globals['_REQUESTINITCHAIN']._serialized_start=1275
  _globals['_REQUESTINITCHAIN']._serialized_end=1532
  _globals['_REQUESTQUERY']._serialized_start=1534
  _globals['_REQUESTQUERY']._serialized_end=1607
  _globals['_REQUESTBEGINBLOCK']._serialized_start=1610
  _globals['_REQUESTBEGINBLOCK']._serialized_end=1819
  _globals['_REQUESTCHECKTX']._serialized_start=1821
  _globals['_REQUESTCHECKTX']._serialized_end=1893
  _globals['_REQUESTDELIVERTX']._serialized_start=1895
  _globals['_REQUESTDELIVERTX']._serialized_end=1925
  _globals['_REQUESTENDBLOCK']._serialized_start=1927
  _globals['_REQUESTENDBLOCK']._serialized_end=1960
  _globals['_REQUESTCOMMIT']._serialized_start=1962
  _globals['_REQUESTCOMMIT']._serialized_end=1977
  _globals['_REQUESTLISTSNAPSHOTS']._serialized_start=1979
  _globals['_REQUESTLISTSNAPSHOTS']._serialized_end=2001
  _globals['_REQUESTOFFERSNAPSHOT']._serialized_start=2003
  _globals['_REQUESTOFFERSNAPSHOT']._serialized_end=2088
  _globals['_REQUESTLOADSNAPSHOTCHUNK']._serialized_start=2090
  _globals['_REQUESTLOADSNAPSHOTCHUNK']._serialized_end=2163
  _globals['_REQUESTAPPLYSNAPSHOTCHUNK']._serialized_start=2165
  _globals['_REQUESTAPPLYSNAPSHOTCHUNK']._serialized_end=2238
  _globals['_RESPONSE']._serialized_start=2241
  _globals['_RESPONSE']._serialized_end=3188
  _globals['_RESPONSEEXCEPTION']._serialized_start=3190
  _globals['_RESPONSEEXCEPTION']._serialized_end=3224
  _globals['_RESPONSEECHO']._serialized_start=3226
  _globals['_RESPONSEECHO']._serialized_end=3257
  _globals['_RESPONSEFLUSH']._serialized_start=3259
  _globals['_RESPONSEFLUSH']._serialized_end=3274
  _globals['_RESPONSEINFO']._serialized_start=3276
  _globals['_RESPONSEINFO']._serialized_end=3398
  _globals['_RESPONSESETOPTION']._serialized_start=3400
  _globals['_RESPONSESETOPTION']._serialized_end=3460
  _globals['_RESPONSEINITCHAIN']._serialized_start=3463
  _globals['_RESPONSEINITCHAIN']._serialized_end=3620
  _globals['_RESPONSEQUERY']._serialized_start=3623
  _globals['_RESPONSEQUERY']._serialized_end=3805
  _globals['_RESPONSEBEGINBLOCK']._serialized_start=3807
  _globals['_RESPONSEBEGINBLOCK']._serialized_end=3893
  _globals['_RESPONSECHECKTX']._serialized_start=3896
  _globals['_RESPONSECHECKTX']._serialized_end=4113
  _globals['_RESPONSEDELIVERTX']._serialized_start=4116
  _globals['_RESPONSEDELIVERTX']._serialized_end=4335
  _globals['_RESPONSEENDBLOCK']._serialized_start=4338
  _globals['_RESPONSEENDBLOCK']._serialized_end=4556
  _globals['_RESPONSECOMMIT']._serialized_start=4558
  _globals['_RESPONSECOMMIT']._serialized_end=4611
  _globals['_RESPONSELISTSNAPSHOTS']._serialized_start=4613
  _globals['_RESPONSELISTSNAPSHOTS']._serialized_end=4682
  _globals['_RESPONSEOFFERSNAPSHOT']._serialized_start=4685
  _globals['_RESPONSEOFFERSNAPSHOT']._serialized_end=4867
  _globals['_RESPONSEOFFERSNAPSHOT_RESULT']._serialized_start=4773
  _globals['_RESPONSEOFFERSNAPSHOT_RESULT']._serialized_end=4867
  _globals['_RESPONSELOADSNAPSHOTCHUNK']._serialized_start=4869
  _globals['_RESPONSELOADSNAPSHOTCHUNK']._serialized_end=4911
  _globals['_RESPONSEAPPLYSNAPSHOTCHUNK']._serialized_start=4914
  _globals['_RESPONSEAPPLYSNAPSHOTCHUNK']._serialized_end=5156
  _globals['_RESPONSEAPPLYSNAPSHOTCHUNK_RESULT']._serialized_start=5060
  _globals['_RESPONSEAPPLYSNAPSHOTCHUNK_RESULT']._serialized_end=5156
  _globals['_CONSENSUSPARAMS']._serialized_start=5159
  _globals['_CONSENSUSPARAMS']._serialized_end=5377
  _globals['_BLOCKPARAMS']._serialized_start=5379
  _globals['_BLOCKPARAMS']._serialized_end=5428
  _globals['_LASTCOMMITINFO']._serialized_start=5430
  _globals['_LASTCOMMITINFO']._serialized_end=5509
  _globals['_EVENT']._serialized_start=5511
  _globals['_EVENT']._serialized_end=5615
  _globals['_EVENTATTRIBUTE']._serialized_start=5617
  _globals['_EVENTATTRIBUTE']._serialized_end=5676
  _globals['_TXRESULT']._serialized_start=5678
  _globals['_TXRESULT']._serialized_end=5789
  _globals['_VALIDATOR']._serialized_start=5791
  _globals['_VALIDATOR']._serialized_end=5834
  _globals['_VALIDATORUPDATE']._serialized_start=5836
  _globals['_VALIDATORUPDATE']._serialized_end=5921
  _globals['_VOTEINFO']._serialized_start=5923
  _globals['_VOTEINFO']._serialized_end=6013
  _globals['_EVIDENCE']._serialized_start=6016
  _globals['_EVIDENCE']._serialized_end=6220
  _globals['_SNAPSHOT']._serialized_start=6222
  _globals['_SNAPSHOT']._serialized_end=6312
  _globals['_ABCIAPPLICATION']._serialized_start=6448
  _globals['_ABCIAPPLICATION']._serialized_end=7731
# @@protoc_insertion_point(module_scope)



from cometbft.services.version.v1 import version_pb2 as _version_pb2
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor



from amino import amino_pb2 as _amino_pb2
from gogoproto import gogo_pb2 as _gogo_pb2
from google.api import annotations_pb2 as _annotations_pb2
from cosmos.base.query.v1beta1 import pagination_pb2 as _pagination_pb2
from neurion.sanctum import params_pb2 as _params_pb2
from neurion.sanctum import dataset_application_pb2 as _dataset_application_pb2
from neurion.sanctum import dataset_usage_request_pb2 as _dataset_usage_request_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class QueryParamsRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class QueryParamsResponse(_message.Message):
    __slots__ = ("params",)
    PARAMS_FIELD_NUMBER: _ClassVar[int]
    params: _params_pb2.Params
    def __init__(self, params: _Optional[_Union[_params_pb2.Params, _Mapping]] = ...) -> None: ...

class QueryGetAvailableDatasetsRequest(_message.Message):
    __slots__ = ("offset", "limit")
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    LIMIT_FIELD_NUMBER: _ClassVar[int]
    offset: int
    limit: int
    def __init__(self, offset: _Optional[int] = ..., limit: _Optional[int] = ...) -> None: ...

class QueryGetAvailableDatasetsResponse(_message.Message):
    __slots__ = ("datasets", "pagination")
    DATASETS_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    datasets: _containers.RepeatedCompositeFieldContainer[_dataset_application_pb2.DatasetApplication]
    pagination: _pagination_pb2.PageResponse
    def __init__(self, datasets: _Optional[_Iterable[_Union[_dataset_application_pb2.DatasetApplication, _Mapping]]] = ..., pagination: _Optional[_Union[_pagination_pb2.PageResponse, _Mapping]] = ...) -> None: ...

class QueryGetApprovedUsageRequestsRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class QueryGetApprovedUsageRequestsResponse(_message.Message):
    __slots__ = ("requests",)
    REQUESTS_FIELD_NUMBER: _ClassVar[int]
    requests: _containers.RepeatedCompositeFieldContainer[_dataset_usage_request_pb2.DatasetUsageRequest]
    def __init__(self, requests: _Optional[_Iterable[_Union[_dataset_usage_request_pb2.DatasetUsageRequest, _Mapping]]] = ...) -> None: ...

class QueryGetRewardRequest(_message.Message):
    __slots__ = ("user",)
    USER_FIELD_NUMBER: _ClassVar[int]
    user: str
    def __init__(self, user: _Optional[str] = ...) -> None: ...

class QueryGetRewardResponse(_message.Message):
    __slots__ = ("reward",)
    REWARD_FIELD_NUMBER: _ClassVar[int]
    reward: int
    def __init__(self, reward: _Optional[int] = ...) -> None: ...

class QueryGetStakeRequest(_message.Message):
    __slots__ = ("user",)
    USER_FIELD_NUMBER: _ClassVar[int]
    user: str
    def __init__(self, user: _Optional[str] = ...) -> None: ...

class QueryGetStakeResponse(_message.Message):
    __slots__ = ("stake",)
    STAKE_FIELD_NUMBER: _ClassVar[int]
    stake: int
    def __init__(self, stake: _Optional[int] = ...) -> None: ...

class QueryGetPendingDatasetsRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class QueryGetPendingDatasetsResponse(_message.Message):
    __slots__ = ("datasets",)
    DATASETS_FIELD_NUMBER: _ClassVar[int]
    datasets: _containers.RepeatedCompositeFieldContainer[_dataset_application_pb2.DatasetApplication]
    def __init__(self, datasets: _Optional[_Iterable[_Union[_dataset_application_pb2.DatasetApplication, _Mapping]]] = ...) -> None: ...

class QueryGetPendingUsageRequestsRequest(_message.Message):
    __slots__ = ("user",)
    USER_FIELD_NUMBER: _ClassVar[int]
    user: str
    def __init__(self, user: _Optional[str] = ...) -> None: ...

class QueryGetPendingUsageRequestsResponse(_message.Message):
    __slots__ = ("requests",)
    REQUESTS_FIELD_NUMBER: _ClassVar[int]
    requests: _containers.RepeatedCompositeFieldContainer[_dataset_usage_request_pb2.DatasetUsageRequest]
    def __init__(self, requests: _Optional[_Iterable[_Union[_dataset_usage_request_pb2.DatasetUsageRequest, _Mapping]]] = ...) -> None: ...

class QueryGetDatasetRequest(_message.Message):
    __slots__ = ("id",)
    ID_FIELD_NUMBER: _ClassVar[int]
    id: int
    def __init__(self, id: _Optional[int] = ...) -> None: ...

class QueryGetDatasetResponse(_message.Message):
    __slots__ = ("dataset",)
    DATASET_FIELD_NUMBER: _ClassVar[int]
    dataset: _dataset_application_pb2.DatasetApplication
    def __init__(self, dataset: _Optional[_Union[_dataset_application_pb2.DatasetApplication, _Mapping]] = ...) -> None: ...

class QueryGetUsageRequestRequest(_message.Message):
    __slots__ = ("id",)
    ID_FIELD_NUMBER: _ClassVar[int]
    id: int
    def __init__(self, id: _Optional[int] = ...) -> None: ...

class QueryGetUsageRequestResponse(_message.Message):
    __slots__ = ("request",)
    REQUEST_FIELD_NUMBER: _ClassVar[int]
    request: _dataset_usage_request_pb2.DatasetUsageRequest
    def __init__(self, request: _Optional[_Union[_dataset_usage_request_pb2.DatasetUsageRequest, _Mapping]] = ...) -> None: ...

class QueryGetUsageRequestsForDatasetRequest(_message.Message):
    __slots__ = ("dataset_id", "offset", "limit")
    DATASET_ID_FIELD_NUMBER: _ClassVar[int]
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    LIMIT_FIELD_NUMBER: _ClassVar[int]
    dataset_id: int
    offset: int
    limit: int
    def __init__(self, dataset_id: _Optional[int] = ..., offset: _Optional[int] = ..., limit: _Optional[int] = ...) -> None: ...

class QueryGetUsageRequestsForDatasetResponse(_message.Message):
    __slots__ = ("requests", "pagination")
    REQUESTS_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    requests: _containers.RepeatedCompositeFieldContainer[_dataset_usage_request_pb2.DatasetUsageRequest]
    pagination: _pagination_pb2.PageResponse
    def __init__(self, requests: _Optional[_Iterable[_Union[_dataset_usage_request_pb2.DatasetUsageRequest, _Mapping]]] = ..., pagination: _Optional[_Union[_pagination_pb2.PageResponse, _Mapping]] = ...) -> None: ...

class QueryGetUsageRequestsForUserRequest(_message.Message):
    __slots__ = ("user", "offset", "limit")
    USER_FIELD_NUMBER: _ClassVar[int]
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    LIMIT_FIELD_NUMBER: _ClassVar[int]
    user: str
    offset: int
    limit: int
    def __init__(self, user: _Optional[str] = ..., offset: _Optional[int] = ..., limit: _Optional[int] = ...) -> None: ...

class QueryGetUsageRequestsForUserResponse(_message.Message):
    __slots__ = ("requests", "pagination")
    REQUESTS_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    requests: _containers.RepeatedCompositeFieldContainer[_dataset_usage_request_pb2.DatasetUsageRequest]
    pagination: _pagination_pb2.PageResponse
    def __init__(self, requests: _Optional[_Iterable[_Union[_dataset_usage_request_pb2.DatasetUsageRequest, _Mapping]]] = ..., pagination: _Optional[_Union[_pagination_pb2.PageResponse, _Mapping]] = ...) -> None: ...

class QueryGetDatasetsForUserRequest(_message.Message):
    __slots__ = ("user", "offset", "limit")
    USER_FIELD_NUMBER: _ClassVar[int]
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    LIMIT_FIELD_NUMBER: _ClassVar[int]
    user: str
    offset: int
    limit: int
    def __init__(self, user: _Optional[str] = ..., offset: _Optional[int] = ..., limit: _Optional[int] = ...) -> None: ...

class QueryGetDatasetsForUserResponse(_message.Message):
    __slots__ = ("datasets", "pagination")
    DATASETS_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    datasets: _containers.RepeatedCompositeFieldContainer[_dataset_application_pb2.DatasetApplication]
    pagination: _pagination_pb2.PageResponse
    def __init__(self, datasets: _Optional[_Iterable[_Union[_dataset_application_pb2.DatasetApplication, _Mapping]]] = ..., pagination: _Optional[_Union[_pagination_pb2.PageResponse, _Mapping]] = ...) -> None: ...



from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Txs(_message.Message):
    __slots__ = ("txs",)
    TXS_FIELD_NUMBER: _ClassVar[int]
    txs: _containers.RepeatedScalarFieldContainer[bytes]
    def __init__(self, txs: _Optional[_Iterable[bytes]] = ...) -> None: ...

class Message(_message.Message):
    __slots__ = ("txs",)
    TXS_FIELD_NUMBER: _ClassVar[int]
    txs: Txs
    def __init__(self, txs: _Optional[_Union[Txs, _Mapping]] = ...) -> None: ...



from ibc.core.channel.v1 import channel_pb2 as _channel_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class QueryAppVersionRequest(_message.Message):
    __slots__ = ("port_id", "connection_id", "ordering", "counterparty", "proposed_version")
    PORT_ID_FIELD_NUMBER: _ClassVar[int]
    CONNECTION_ID_FIELD_NUMBER: _ClassVar[int]
    ORDERING_FIELD_NUMBER: _ClassVar[int]
    COUNTERPARTY_FIELD_NUMBER: _ClassVar[int]
    PROPOSED_VERSION_FIELD_NUMBER: _ClassVar[int]
    port_id: str
    connection_id: str
    ordering: _channel_pb2.Order
    counterparty: _channel_pb2.Counterparty
    proposed_version: str
    def __init__(self, port_id: _Optional[str] = ..., connection_id: _Optional[str] = ..., ordering: _Optional[_Union[_channel_pb2.Order, str]] = ..., counterparty: _Optional[_Union[_channel_pb2.Counterparty, _Mapping]] = ..., proposed_version: _Optional[str] = ...) -> None: ...

class QueryAppVersionResponse(_message.Message):
    __slots__ = ("port_id", "version")
    PORT_ID_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    port_id: str
    version: str
    def __init__(self, port_id: _Optional[str] = ..., version: _Optional[str] = ...) -> None: ...
